@@ -13,4 +13,12 @@ str(x)
 
 stopifnot(identical(x, val))
 
+dbInsert(db, "b", 1:10)
+dbList(db)
+
+dbFetch(db, "b")
+dbMultiFetch(db, c("a", "b")) |> 
+        str()
+
 dbDisconnect(db)
+
